@@ -57,3 +57,11 @@ class managed_missions:
     if not Utils.is_success(result['status_code']):
       raise Exception(f"Failed to retrieve donors. Result: {result}")
     return result
+
+  def get_trip_donors(self, mission_trip_id, **kw):
+    post_url = f"{self.base_url}/DonorAPI/GetByMissionTrip"
+    kw['missionTripId'] = mission_trip_id
+    result = get(post_url, self.headers, params=kw)
+    if not Utils.is_success(result['status_code']):
+      raise Exception(f"Failed to retrieve trip donors. Result: {result}")
+    return result
