@@ -22,7 +22,7 @@ def authenticate(force=False):
     if 'access_token' not in auth_result.keys():
       raise Exception(f"Access token not returned: {result}")
     CONFIG['access_token'] = auth_result['access_token']
-    HEADERS['Authorization'] = f"Bearer {CONFIG['access_token']}"
+    HEADERS['Authorization'] = f"Zoho-oauthtoken {CONFIG['access_token']}"
     CONFIG['expires_at'] = Utils.now() + (auth_result['expires_in'] * 1000)
 
 
